@@ -7,7 +7,7 @@ if(!require("boot"))stop("this test requires boot.")
 if(!require("MASS"))stop("this test requires MASS.")
 if(!require("survC1"))stop("this test requires survC1.")
 
-cat("frailtypack test for additive model ...\n")
+cat("frailtypack test for additive model ...")
 
 
 ########################################################################
@@ -44,4 +44,4 @@ par(mfrow = c(1,2))
 plot(modAdd2cov.withoutCorr, type.plot = "hazard", main = "Correlation=False",
   conf.bands = TRUE)
 plot(modAdd2cov.withCorr, type.plot = "hazard", main = "Correlation=True",
-  conf.bands = TRUE)
+  conf.bands = TRUE)
\ No newline at end of file
